@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminProcessManagementTransition;
@@ -11,8 +11,8 @@ package Kernel::Modules::AdminProcessManagementTransition;
 use strict;
 use warnings;
 
-use Kernel::System::VariableCheck qw(:all);
 use Kernel::Language qw(Translatable);
+use Kernel::System::VariableCheck qw(:all);
 
 our $ObjectManagerDisabled = 1;
 
@@ -154,6 +154,8 @@ sub Run {
             EntityID => $EntityID,
         );
 
+        my $ConfigJSON = $LayoutObject->JSONEncode( Data => $TransitionConfig );
+
         # check if needed to open another window or if popup should go back
         if ( $Redirect && $Redirect eq '1' ) {
 
@@ -177,7 +179,7 @@ sub Run {
                     ID        => $RedirectID,
                     EntityID  => $RedirectID,
                 },
-                ConfigJSON => $TransitionConfig,
+                ConfigJSON => $ConfigJSON,
             );
         }
         else {
@@ -191,7 +193,7 @@ sub Run {
                 # close the popup
                 return $Self->_PopupResponse(
                     ClosePopup => 1,
-                    ConfigJSON => $TransitionConfig,
+                    ConfigJSON => $ConfigJSON,
                 );
             }
             else {
@@ -200,7 +202,7 @@ sub Run {
                 return $Self->_PopupResponse(
                     Redirect   => 1,
                     Screen     => $LastScreen,
-                    ConfigJSON => $TransitionConfig,
+                    ConfigJSON => $ConfigJSON,
                 );
             }
         }
@@ -328,6 +330,8 @@ sub Run {
             EntityID => $TransitionData->{EntityID},
         );
 
+        my $ConfigJSON = $LayoutObject->JSONEncode( Data => $TransitionConfig );
+
         # check if needed to open another window or if popup should go back
         if ( $Redirect && $Redirect eq '1' ) {
 
@@ -351,7 +355,7 @@ sub Run {
                     ID        => $RedirectID,
                     EntityID  => $RedirectID,
                 },
-                ConfigJSON => $TransitionConfig,
+                ConfigJSON => $ConfigJSON,
             );
         }
         else {
@@ -365,7 +369,7 @@ sub Run {
                 # close the popup
                 return $Self->_PopupResponse(
                     ClosePopup => 1,
-                    ConfigJSON => $TransitionConfig,
+                    ConfigJSON => $ConfigJSON,
                 );
             }
             else {
@@ -374,7 +378,7 @@ sub Run {
                 return $Self->_PopupResponse(
                     Redirect   => 1,
                     Screen     => $LastScreen,
-                    ConfigJSON => $TransitionConfig,
+                    ConfigJSON => $ConfigJSON,
                 );
             }
         }
@@ -389,7 +393,6 @@ sub Run {
         # close the popup
         return $Self->_PopupResponse(
             ClosePopup => 1,
-            ConfigJSON => '',
         );
     }
 
@@ -513,8 +516,7 @@ sub _ShowEdit {
             SelectedID  => $TransitionData->{Config}->{ConditionLinking},
         );
 
-        my @Conditions = sort { ( $a =~ m/^(\d+)/ )[0] <=> ( $b =~ m/^(\d+)/ )[0] }
-            keys %{ $TransitionData->{Config}->{Condition} };
+        my @Conditions = sort keys %{ $TransitionData->{Config}->{Condition} };
 
         for my $Condition (@Conditions) {
 
@@ -588,7 +590,7 @@ sub _ShowEdit {
                 Name => 'EditWarning',
                 Data => {
                     ProcessList => join( ', ', @{$AffectedProcesses} ),
-                }
+                    }
             );
         }
     }
@@ -664,15 +666,15 @@ sub _GetParams {
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     # get parameters from web browser
-    $GetParam->{Name}            = $ParamObject->GetParam( Param => 'Name' ) || '';
+    $GetParam->{Name} = $ParamObject->GetParam( Param => 'Name' ) || '';
     $GetParam->{ConditionConfig} = $ParamObject->GetParam( Param => 'ConditionConfig' )
         || '';
 
     my $Config = $Kernel::OM->Get('Kernel::System::JSON')->Decode(
         Data => $GetParam->{ConditionConfig}
     );
-    $GetParam->{Config}                     = {};
-    $GetParam->{Config}->{Condition}        = $Config;
+    $GetParam->{Config} = {};
+    $GetParam->{Config}->{Condition} = $Config;
     $GetParam->{Config}->{ConditionLinking} = $ParamObject->GetParam( Param => 'OverallConditionLinking' ) || '';
 
     return $GetParam;
@@ -718,7 +720,7 @@ sub _PushSessionScreen {
 
     # add screen to the screen path
     push @{ $Self->{ScreensPath} }, {
-        Action    => $Self->{Action} || '',
+        Action => $Self->{Action} || '',
         Subaction => $Param{Subaction},
         ID        => $Param{ID},
         EntityID  => $Param{EntityID},
@@ -745,24 +747,20 @@ sub _PopupResponse {
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     if ( $Param{Redirect} && $Param{Redirect} eq 1 ) {
-
-        # send data to JS
-        $LayoutObject->AddJSData(
-            Key   => 'Redirect',
-            Value => {
+        $LayoutObject->Block(
+            Name => 'Redirect',
+            Data => {
                 ConfigJSON => $Param{ConfigJSON},
                 %{ $Param{Screen} },
-            }
+            },
         );
     }
     elsif ( $Param{ClosePopup} && $Param{ClosePopup} eq 1 ) {
-
-        # send data to JS
-        $LayoutObject->AddJSData(
-            Key   => 'ClosePopup',
-            Value => {
+        $LayoutObject->Block(
+            Name => 'ClosePopup',
+            Data => {
                 ConfigJSON => $Param{ConfigJSON},
-            }
+            },
         );
     }
 
