@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Dashboard::EventsTicketCalendar;
@@ -118,7 +118,7 @@ sub Run {
     my %Tickets;
     if (%QueuesConfigured) {
         %Tickets = $TicketObject->TicketSearch(
-            SortBy   => $ConfigObject->{'SortBy::Default'} || 'Age',
+            SortBy => $ConfigObject->{'SortBy::Default'} || 'Age',
             QueueIDs => [ sort keys %QueuesConfigured ],
             UserID   => $Self->{UserID},
             StateIDs => \@ViewableStateIDs,
@@ -133,10 +133,8 @@ sub Run {
     my $Limit   = scalar keys %Tickets;
 
     # get needed objects
-    my $LayoutObject          = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $UserObject            = $Kernel::OM->Get('Kernel::System::User');
-    my $CustomerUserObject    = $Kernel::OM->Get('Kernel::System::CustomerUser');
-    my $CustomerCompanyObject = $Kernel::OM->Get('Kernel::System::CustomerCompany');
+    my $TimeObject   = $Kernel::OM->Get('Kernel::System::Time');
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     my $Content;
 
@@ -158,32 +156,29 @@ sub Run {
             {
 
                 # end time should be greater than start time
-                my $StartTimeObject = $Kernel::OM->Create(
-                    'Kernel::System::DateTime',
-                    ObjectParams => {
-                        String => $TicketDetail{ 'DynamicField_' . $StartTimeDynamicField }
-                    },
+                my $StartTime = $TimeObject->TimeStamp2SystemTime(
+                    String => $TicketDetail{ 'DynamicField_' . $StartTimeDynamicField },
                 );
-
-                my $EndTimeObject = $Kernel::OM->Create(
-                    'Kernel::System::DateTime',
-                    ObjectParams => {
-                        String => $TicketDetail{ 'DynamicField_' . $EndTimeDynamicField }
-                    },
+                my $EndTime = $TimeObject->TimeStamp2SystemTime(
+                    String => $TicketDetail{ 'DynamicField_' . $EndTimeDynamicField },
                 );
 
                 # check if start time is after end time
-                if ( $StartTimeObject > $EndTimeObject ) {
+                if ( $StartTime > $EndTime ) {
 
                     # turn start and end time around for the calendar view
-                    my $NewStartTimeObject = $EndTimeObject;
-                    my $NewEndTimeObject   = $StartTimeObject;
-                    $StartTimeObject = $NewStartTimeObject;
-                    $EndTimeObject   = $NewEndTimeObject;
+                    my $NewStartTime = $EndTime;
+                    my $NewEndTime   = $StartTime;
+                    $StartTime = $NewStartTime;
+                    $EndTime   = $NewEndTime;
 
                    # we also need to turn the time in the tooltip around, otherwiese the time bar display would be wrong
-                    $TicketDetail{ 'DynamicField_' . $StartTimeDynamicField } = $StartTimeObject->ToString();
-                    $TicketDetail{ 'DynamicField_' . $EndTimeDynamicField }   = $EndTimeObject->ToString();
+                    $TicketDetail{ 'DynamicField_' . $StartTimeDynamicField } = $TimeObject->SystemTime2TimeStamp(
+                        SystemTime => $StartTime,
+                    );
+                    $TicketDetail{ 'DynamicField_' . $EndTimeDynamicField } = $TimeObject->SystemTime2TimeStamp(
+                        SystemTime => $EndTime,
+                    );
 
                     # show a notification bar to indicate that the start and end time are set in a wrong way
                     $Content .= $LayoutObject->Notify(
@@ -194,31 +189,24 @@ sub Run {
                 }
 
                 my %Data;
-
-                # set start/end time individual units
-                # ex: SYear; EMinute
-                my $SetDataDateTimeUnits = sub {
-                    my ( $Type, $Details ) = @_;
-
-                    my $Prefix = substr( $Type, 0, 1 );
-                    for my $Unit (qw(Year Month Day Hour Minute Second)) {
-                        my $Value = $Details->{$Unit};
-                        if ( $Unit eq 'Month' ) {
-                            $Value -= 1;
-                        }
-
-                        $Data{"${Prefix}${Unit}"} = $Value;
-                    }
-
-                    return;
-                };
-
-                $SetDataDateTimeUnits->( Start => $StartTimeObject->Get() );
-                $SetDataDateTimeUnits->( End   => $EndTimeObject->Get() );
-                #
-
-                $Data{ID}        = $TicketID;
-                $Data{Title}     = $TicketDetail{Title};
+                $Data{ID}    = $TicketID;
+                $Data{Title} = $TicketDetail{Title};
+                $TicketDetail{ 'DynamicField_' . $StartTimeDynamicField }
+                    =~ /(\d+)\-(\d+)\-(\d+)\ (\d+)\:(\d+)\:(\d+)/;
+                $Data{SYear}   = $1;
+                $Data{SMonth}  = $2 - 1;
+                $Data{SDay}    = $3;
+                $Data{SHour}   = $4;
+                $Data{SMinute} = $5;
+                $Data{SSecond} = $6;
+                $TicketDetail{ 'DynamicField_' . $EndTimeDynamicField }
+                    =~ /(\d+)\-(\d+)\-(\d+)\ (\d+)\:(\d+)\:(\d+)/;
+                $Data{EYear}     = $1;
+                $Data{EMonth}    = $2 - 1;
+                $Data{EDay}      = $3;
+                $Data{EHour}     = $4;
+                $Data{EMinute}   = $5;
+                $Data{ESecond}   = $6;
                 $Data{Color}     = $Self->{TicketColors}->{$TicketID};
                 $Data{AllDay}    = 'false';
                 $Data{Url}       = "index.pl?Action=AgentTicketZoom;TicketID=$TicketID";
@@ -231,7 +219,16 @@ sub Run {
                 # dates are exactly the same (ESecond is 00 normally)
                 $Data{ESecond}++;
 
-                push @{ $Self->{EventsTicketCalendar} }, \%Data;
+                $LayoutObject->Block(
+                    Name => 'CalendarEvent',
+                    Data => \%Data,
+                );
+
+                if ( $Counter < $Limit ) {
+                    $LayoutObject->Block(
+                        Name => 'CalendarEventComma',
+                    );
+                }
 
                 # add ticket info container
                 $LayoutObject->Block(
@@ -266,26 +263,12 @@ sub Run {
                             next TICKETFIELD;
                         }
 
-                        if ( $Key eq 'CustomerName' && $TicketDetail{CustomerUserID} ) {
-                            $TicketDetail{$Key} = $CustomerUserObject->CustomerName(
-                                UserLogin => $TicketDetail{CustomerUserID},
+                        if ( $Key eq 'CustomerUserID' && $TicketDetail{$Key} ) {
+                            $TicketDetail{$Key} = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
+                                UserLogin => $TicketDetail{$Key},
                             );
                         }
 
-                        if ( $Key eq 'CustomerCompanyName' && $TicketDetail{CustomerID} ) {
-                            my %CustomerCompany = $CustomerCompanyObject->CustomerCompanyGet(
-                                CustomerID => $TicketDetail{CustomerID},
-                            );
-                            $TicketDetail{$Key} = $CustomerCompany{$Key};
-                        }
-
-                        if ( ( $Key eq 'Owner' || $Key eq 'Responsible' ) && $TicketDetail{$Key} ) {
-                            my %UserData = $UserObject->GetUserData(
-                                User => $TicketDetail{$Key},
-                            );
-                            $TicketDetail{$Key} = $UserData{UserFullname};
-                        }
-
                         # translate state and priority name
                         if ( ( $Key eq 'State' || $Key eq 'Priority' ) && $TicketDetail{$Key} ) {
                             $TicketDetail{$Key} = $LayoutObject->{LanguageObject}->Translate( $TicketDetail{$Key} );
@@ -345,28 +328,26 @@ sub Run {
             }
         }
     }
+    if ( $Counter < $Limit ) {
+        $LayoutObject->Block(
+            Name => 'CalendarEventComma',
+        );
+    }
 
     $LayoutObject->Block(
         Name => 'CalendarDiv',
         Data => {
             CalendarWidth => $ConfigObject->{DashboardEventsTicketCalendar}->{CalendarWidth}
                 || 95,
-        }
-    );
-
-    # send data to JS
-    $LayoutObject->AddJSData(
-        Key   => 'EventsTicketCalendar',
-        Value => $Self->{EventsTicketCalendar},
-    );
-    $LayoutObject->AddJSData(
-        Key   => 'FirstDay',
-        Value => $ConfigObject->Get('CalendarWeekDayStart') || 0,
+            }
     );
 
     $Content .= $LayoutObject->Output(
         TemplateFile => 'DashboardEventsTicketCalendar',
-        Data         => {},
+        Data         => {
+            %{ $Self->{Config} },
+            FirstDay => $Kernel::OM->Get('Kernel::Config')->Get('CalendarWeekDayStart') || 0,
+        },
     );
 
     return $Content;
