@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Dashboard::RSS;
@@ -11,7 +11,6 @@ package Kernel::Output::HTML::Dashboard::RSS;
 use strict;
 use warnings;
 
-use LWP::UserAgent;
 use XML::FeedPP;
 
 our $ObjectManagerDisabled = 1;
@@ -72,24 +71,11 @@ sub Run {
         }
     }
 
-    # Configure a local instance of LWP::UserAgent for passing to XML::FeedPP.
-    my $UserAgent = LWP::UserAgent->new();
-
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
-    # In some scenarios like transparent HTTPS proxies, it can be necessary to turn off
-    #   SSL certificate validation.
-    if ( $ConfigObject->Get('WebUserAgent::DisableSSLVerification') ) {
-        $UserAgent->ssl_opts(
-            verify_hostname => 0,
-        );
-    }
-
-    # Set proxy settings if configured, and make sure to allow all supported protocols
-    #   (please see bug#12512 for more information).
-    my $Proxy = $ConfigObject->Get('WebUserAgent::Proxy');
+    # set proxy settings can't use Kernel::System::WebAgent because of used
+    # XML::FeedPP to get RSS files
+    my $Proxy = $Kernel::OM->Get('Kernel::Config')->Get('WebUserAgent::Proxy');
     if ($Proxy) {
-        $UserAgent->proxy( [ 'http', 'https', 'ftp' ], $Proxy );
+        $ENV{CGI_HTTP_PROXY} = $Proxy;    ## no critic
     }
 
     # get content
@@ -100,18 +86,21 @@ sub Run {
         $Feed = eval {
             XML::FeedPP->new(
                 $FeedURL,
-                'xml_deref'     => 1,
-                'utf8_flag'     => 1,
-                'lwp_useragent' => $UserAgent,
+                'xml_deref' => 1,
+                'utf8_flag' => 1,
             );
         };
         last TRY if $Feed;
     }
 
     if ( !$Feed ) {
-        return $LayoutObject->{LanguageObject}->Translate( 'Can\'t connect to %s!', $FeedURL );
+        my $Content = "Can't connect to $FeedURL";
+        return $Content;
     }
 
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
     my $Count = 0;
     ITEM:
     for my $Item ( $Feed->get_item() ) {
@@ -120,16 +109,10 @@ sub Run {
         my $Time = $Item->pubDate();
         my $Ago;
         if ($Time) {
-            my $SystemDateTimeObject = $Kernel::OM->Create(
-                'Kernel::System::DateTime',
-                ObjectParams => {
-                    String => $Time,
-                },
+            my $SystemTime = $TimeObject->TimeStamp2SystemTime(
+                String => $Time,
             );
-
-            my $CurSystemDateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-
-            $Ago = $CurSystemDateTimeObject->ToEpoch() - $SystemDateTimeObject->ToEpoch();
+            $Ago = $TimeObject->SystemTime() - $SystemTime;
             $Ago = $LayoutObject->CustomerAge(
                 Age   => $Ago,
                 Space => ' ',
