@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,8 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
 
+use Kernel::Language qw(Translatable);
+
 use base qw(Kernel::System::DynamicField::Driver::BaseDateTime);
 
 our @ObjectDependencies = (
@@ -63,7 +65,7 @@ sub new {
         'IsCustomerInterfaceCapable'   => 1,
     };
 
-    # get the Dynamic Field Backend custmom extensions
+    # get the Dynamic Field Backend custom extensions
     my $DynamicFieldDriverExtensions
         = $Kernel::OM->Get('Kernel::Config')->Get('DynamicFields::Extension::Driver::Date');
 
@@ -89,7 +91,7 @@ sub new {
             }
         }
 
-        # check if extension contains more behabiors
+        # check if extension contains more behaviors
         if ( IsHashRefWithData( $Extension->{Behaviors} ) ) {
 
             %{ $Self->{Behaviors} } = (
@@ -105,10 +107,6 @@ sub new {
 sub ValueSet {
     my ( $Self, %Param ) = @_;
 
-    # Convert the ISO date string to a ISO date time string, if only the date is given to
-    #   have the correct format.
-    $Param{Value} = $Self->_ConvertDate2DateTime( $Param{Value} );
-
     # check for no time in date fields
     if ( $Param{Value} && $Param{Value} !~ m{\A \d{4}-\d{2}-\d{2}\s00:00:00 \z}xms ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -139,10 +137,6 @@ sub ValueValidate {
     my $Prefix          = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
     my $DateRestriction = $Param{DynamicFieldConfig}->{Config}->{DateRestriction};
 
-    # Convert the ISO date string to a ISO date time string, if only the date is given to
-    #   have the correct format.
-    $Param{Value} = $Self->_ConvertDate2DateTime( $Param{Value} );
-
     # check for no time in date fields
     if (
         $Param{Value}
@@ -152,7 +146,7 @@ sub ValueValidate {
     {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "The value for the Date field ($Param{DynamicFieldConfig}->{Name}) is invalid!\n"
+            Message  => "The value for the field Date is invalid!\n"
                 . "The date must be valid and the time must be 00:00:00"
                 . " (or 23:59:59 for search parameters)",
         );
@@ -175,20 +169,39 @@ sub ValueValidate {
             String => $Param{Value},
         );
         my $SystemTime = $TimeObject->SystemTime();
+        my ( $SystemTimePast, $SystemTimeFuture ) = $SystemTime;
 
-        if ( $DateRestriction eq 'DisableFutureDates' && $ValueSystemTime > $SystemTime ) {
+        # if validating date only value, allow today for selection
+        if ( $Param{DynamicFieldConfig}->{FieldType} eq 'Date' ) {
+
+            # calculate today system time boundaries
+            my @Today = $TimeObject->SystemTime2Date(
+                SystemTime => $SystemTime,
+            );
+            $SystemTimePast = $TimeObject->Date2SystemTime(
+                Year   => $Today[5],
+                Month  => $Today[4],
+                Day    => $Today[3],
+                Hour   => 0,
+                Minute => 0,
+                Second => 0,
+            );
+            $SystemTimeFuture = $SystemTimePast + 60 * 60 * 24 - 1;    # 23:59:59
+        }
+
+        if ( $DateRestriction eq 'DisableFutureDates' && $ValueSystemTime > $SystemTimeFuture ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message =>
-                    "The value for the Date field ($Param{DynamicFieldConfig}->{Name}) is in the future! The date needs to be in the past!",
+                    "The value for the field Date is in the future! The date needs to be in the past!",
             );
             return;
         }
-        elsif ( $DateRestriction eq 'DisablePastDates' && $ValueSystemTime < $SystemTime ) {
+        elsif ( $DateRestriction eq 'DisablePastDates' && $ValueSystemTime < $SystemTimePast ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message =>
-                    "The value for the Date field ($Param{DynamicFieldConfig}->{Name}) is in the past! The date needs to be in the future!",
+                    "The value for the field Date is in the past! The date needs to be in the future!",
             );
             return;
         }
@@ -209,14 +222,15 @@ sub SearchSQLGet {
     );
 
     if ( $Operators{ $Param{Operator} } ) {
-
-        # Convert the ISO date string to a ISO date time string, if only the date is given to
-        #   have the correct format.
-        $Param{SearchTerm} = $Self->_ConvertDate2DateTime( $Param{SearchTerm} );
-
         my $SQL = " $Param{TableAlias}.value_date $Operators{$Param{Operator}} '"
-            . $Kernel::OM->Get('Kernel::System::DB')->Quote( $Param{SearchTerm} ) . "' ";
+            . $Kernel::OM->Get('Kernel::System::DB')->Quote( $Param{SearchTerm} );
 
+        # Append hh:mm:ss if only the ISO date was supplied to get a full date-time string.
+        if ( $Param{SearchTerm} =~ m{\A \d{4}-\d{2}-\d{2}\z}xms ) {
+            $SQL .= " 00:00:00";
+        }
+
+        $SQL .= "' ";
         return $SQL;
     }
 
@@ -243,6 +257,7 @@ sub EditFieldRender {
         $Value = $FieldConfig->{DefaultValue} || '';
     }
 
+    my %SplitedFieldValues;
     if ( defined $Param{Value} ) {
         $Value = $Param{Value};
     }
@@ -250,15 +265,18 @@ sub EditFieldRender {
         my ( $Year, $Month, $Day, $Hour, $Minute, $Second ) = $Value =~
             m{ \A ( \d{4} ) - ( \d{2} ) - ( \d{2} ) \s ( \d{2} ) : ( \d{2} ) : ( \d{2} ) \z }xms;
 
-        # If a value is sent this value must be active, then the Used part needs to be set to 1
-        #   otherwise user can easily forget to mark the checkbox and this could lead into data
-        #   lost (Bug#8258).
-        $FieldConfig->{ $FieldName . 'Used' }   = 1;
-        $FieldConfig->{ $FieldName . 'Year' }   = $Year;
-        $FieldConfig->{ $FieldName . 'Month' }  = $Month;
-        $FieldConfig->{ $FieldName . 'Day' }    = $Day;
-        $FieldConfig->{ $FieldName . 'Hour' }   = $Hour;
-        $FieldConfig->{ $FieldName . 'Minute' } = $Minute;
+        %SplitedFieldValues = (
+
+            # if a value is sent this value must be active, then the Used part needs to be set to 1
+            # otherwise user can easily forget to mark the checkbox and this could lead into data
+            # lost Bug#8258
+            $FieldName . 'Used'   => 1,
+            $FieldName . 'Year'   => $Year,
+            $FieldName . 'Month'  => $Month,
+            $FieldName . 'Day'    => $Day,
+            $FieldName . 'Hour'   => $Hour,
+            $FieldName . 'Minute' => $Minute,
+        );
     }
 
     # extract the dynamic field value form the web request
@@ -325,6 +343,7 @@ sub EditFieldRender {
         $FieldName . Optional => 1,
         Validate              => 1,
         %{$FieldConfig},
+        %SplitedFieldValues,
         %YearsPeriodRange,
         OverrideTimeZone => 1,
     );
@@ -416,7 +435,7 @@ sub EditFieldValueGet {
         && !$DynamicFieldValues{ $Prefix . 'Month' }
         && !$DynamicFieldValues{ $Prefix . 'Day' };
 
-    # check if return value structure is nedded
+    # check if return value structure is needed
     if ( defined $Param{ReturnValueStructure} && $Param{ReturnValueStructure} eq '1' ) {
         return \%DynamicFieldValues;
     }
@@ -426,7 +445,7 @@ sub EditFieldValueGet {
         return \%DynamicFieldValues;
     }
 
-    # add secnods, as 0 to the DynamicFieldValues hash
+    # add seconds, as 0 to the DynamicFieldValues hash
     $DynamicFieldValues{ 'DynamicField_' . $Param{DynamicFieldConfig}->{Name} . 'Second' } = 0;
 
     my $ManualTimeStamp = '';
@@ -507,12 +526,31 @@ sub EditFieldValueValidate {
             String => $ManualTimeStamp,
         );
         my $SystemTime = $TimeObject->SystemTime();
+        my ( $SystemTimePast, $SystemTimeFuture ) = $SystemTime;
 
-        if ( $DateRestriction eq 'DisableFutureDates' && $ValueSystemTime > $SystemTime ) {
+        # if validating date only value, allow today for selection
+        if ( $Param{DynamicFieldConfig}->{FieldType} eq 'Date' ) {
+
+            # calculate today system time boundaries
+            my @Today = $TimeObject->SystemTime2Date(
+                SystemTime => $SystemTime,
+            );
+            $SystemTimePast = $TimeObject->Date2SystemTime(
+                Year   => $Today[5],
+                Month  => $Today[4],
+                Day    => $Today[3],
+                Hour   => 0,
+                Minute => 0,
+                Second => 0,
+            );
+            $SystemTimeFuture = $SystemTimePast + 60 * 60 * 24 - 1;    # 23:59:59
+        }
+
+        if ( $DateRestriction eq 'DisableFutureDates' && $ValueSystemTime > $SystemTimeFuture ) {
             $ServerError  = 1;
             $ErrorMessage = "Invalid date (need a past date)!";
         }
-        elsif ( $DateRestriction eq 'DisablePastDates' && $ValueSystemTime < $SystemTime ) {
+        elsif ( $DateRestriction eq 'DisablePastDates' && $ValueSystemTime < $SystemTimePast ) {
             $ServerError  = 1;
             $ErrorMessage = "Invalid date (need a future date)!";
         }
@@ -562,7 +600,7 @@ sub ReadableValueRender {
 
     my $Value = defined $Param{Value} ? $Param{Value} : '';
 
-    # only keep date part, loose time part of timestamp
+    # only keep date part, loose time part of time-stamp
     $Value =~ s{ \A (\d{4} - \d{2} - \d{2}) .+?\z }{$1}xms;
 
     # Title is always equal to Value
@@ -692,15 +730,15 @@ EOF
 
         $HTMLString .= $Param{LayoutObject}->BuildSelection(
             Data => {
-                'Before' => 'more than ... ago',
-                'Last'   => 'within the last ...',
-                'Next'   => 'within the next ...',
-                'After'  => 'in more than ...',
+                'Before' => Translatable('more than ... ago'),
+                'Last'   => Translatable('within the last ...'),
+                'Next'   => Translatable('within the next ...'),
+                'After'  => Translatable('in more than ...'),
             },
             Sort           => 'IndividualKey',
             SortIndividual => [ 'Before', 'Last', 'Next', 'After' ],
             Name           => $FieldName . 'Start',
-            SelectedID     => $Value->{Start}->{ $FieldName . 'Start' } || 'Last',
+            SelectedID => $Value->{Start}->{ $FieldName . 'Start' } || 'Last',
         );
         $HTMLString .= ' ' . $Param{LayoutObject}->BuildSelection(
             Data       => [ 1 .. 59 ],
@@ -709,20 +747,20 @@ EOF
         );
         $HTMLString .= ' ' . $Param{LayoutObject}->BuildSelection(
             Data => {
-                minute => 'minute(s)',
-                hour   => 'hour(s)',
-                day    => 'day(s)',
-                week   => 'week(s)',
-                month  => 'month(s)',
-                year   => 'year(s)',
+                minute => Translatable('minute(s)'),
+                hour   => Translatable('hour(s)'),
+                day    => Translatable('day(s)'),
+                week   => Translatable('week(s)'),
+                month  => Translatable('month(s)'),
+                year   => Translatable('year(s)'),
             },
             Name       => $FieldName . 'Format',
-            SelectedID => $Value->{Format}->{ $FieldName . 'Format' } || 'day',
+            SelectedID => $Value->{Format}->{ $FieldName . 'Format' } || Translatable('day'),
         );
 
         my $AdditionalText;
         if ( $Param{UseLabelHints} ) {
-            $AdditionalText = 'before/after';
+            $AdditionalText = Translatable('before/after');
         }
 
         # call EditLabelRender on the common driver
@@ -740,15 +778,6 @@ EOF
         return $Data;
     }
 
-    # to set the years range
-    my %YearsPeriodRange;
-    if ( defined $FieldConfig->{YearsPeriod} && $FieldConfig->{YearsPeriod} eq '1' ) {
-        %YearsPeriodRange = (
-            YearPeriodPast   => $FieldConfig->{YearsInPast}   || 0,
-            YearPeriodFuture => $FieldConfig->{YearsInFuture} || 0,
-        );
-    }
-
     # build HTML for start value set
     $HTMLString .= $Param{LayoutObject}->BuildDateSelection(
         %Param,
@@ -758,7 +787,6 @@ EOF
         DiffTime             => -( ( 60 * 60 * 24 ) * 30 ),
         Validate             => 1,
         %{ $Value->{ValueStart} },
-        %YearsPeriodRange,
     );
 
     # build HTML for "and" separator
@@ -773,12 +801,11 @@ EOF
         DiffTime             => +( ( 60 * 60 * 24 ) * 30 ),
         Validate             => 1,
         %{ $Value->{ValueStop} },
-        %YearsPeriodRange,
     );
 
     my $AdditionalText;
     if ( $Param{UseLabelHints} ) {
-        $AdditionalText = 'between';
+        $AdditionalText = Translatable('between');
     }
 
     # call EditLabelRender on the common Driver
@@ -845,7 +872,7 @@ sub SearchFieldValueGet {
 
         $DynamicFieldValues{$Prefix} = 1;
 
-        # check if return value structure is nedded
+        # check if return value structure is needed
         if ( defined $Param{ReturnProfileStructure} && $Param{ReturnProfileStructure} eq '1' ) {
             return \%DynamicFieldValues;
         }
@@ -1024,7 +1051,7 @@ sub SearchFieldParameterBuild {
             # get the current time in epoch seconds
             my $Now = $TimeObject->SystemTime();
 
-            # calculate diff time seconds
+            # calculate difference time seconds
             my $DiffTimeSeconds = $DiffTimeMinutes * 60;
 
             my $DisplayValue = '';
@@ -1032,12 +1059,12 @@ sub SearchFieldParameterBuild {
             # define to search before or after that time stamp
             if ( $Start eq 'Before' ) {
 
-                # we must subtract the diff because it is in the past
+                # we must subtract the difference because it is in the past
                 my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $TimeObject->SystemTime2Date(
                     SystemTime => $Now - $DiffTimeSeconds,
                 );
 
-                # use the last hour from diff time as it will be the upper limit strict
+                # use the last hour from difference time as it will be the upper limit strict
                 my $SystemTime = $TimeObject->Date2SystemTime(
                     Year   => $Year,
                     Month  => $Month,
@@ -1077,12 +1104,12 @@ sub SearchFieldParameterBuild {
                     SystemTime => $NowSystemTime,
                 );
 
-                # we must subtract the diff because it is in the past
+                # we must subtract the difference because it is in the past
                 my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $TimeObject->SystemTime2Date(
                     SystemTime => $Now - $DiffTimeSeconds,
                 );
 
-                # use the first hour from diff time as it will be the lower limit relative
+                # use the first hour from difference time as it will be the lower limit relative
                 my $SystemTime = $TimeObject->Date2SystemTime(
                     Year   => $Year,
                     Month  => $Month,
@@ -1125,12 +1152,12 @@ sub SearchFieldParameterBuild {
                     SystemTime => $NowSystemTime,
                 );
 
-                # we must add the diff because it is in the future
+                # we must add the difference because it is in the future
                 my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $TimeObject->SystemTime2Date(
                     SystemTime => $Now + $DiffTimeSeconds,
                 );
 
-                # use the last hour from diff time as it will be the upper limit relative
+                # use the last hour from difference time as it will be the upper limit relative
                 my $SystemTime = $TimeObject->Date2SystemTime(
                     Year   => $Year,
                     Month  => $Month,
@@ -1155,12 +1182,12 @@ sub SearchFieldParameterBuild {
             }
             elsif ( $Start eq 'After' ) {
 
-                # we must add the diff because it is in the future
+                # we must add the difference because it is in the future
                 my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $TimeObject->SystemTime2Date(
                     SystemTime => $Now + $DiffTimeSeconds,
                 );
 
-                # use the last hour from diff time as it will be the lower limit strict
+                # use the last hour from difference time as it will be the lower limit strict
                 my $SystemTime = $TimeObject->Date2SystemTime(
                     Year   => $Year,
                     Month  => $Month,
@@ -1270,7 +1297,7 @@ sub StatsSearchFieldParameterBuild {
         $Sec  = 0;
     }
 
-    # get target time using new values (or same values for onknown operators)
+    # get target time using new values (or same values for unknown operators)
     my $TargetSystemTime = $TimeObject->Date2SystemTime(
         Year   => $Year,
         Month  => $Month,
@@ -1313,54 +1340,8 @@ sub RandomValueSet {
     };
 }
 
-sub ValueLookup {
-    my ( $Self, %Param ) = @_;
-
-    my $Value = defined $Param{Key} ? $Param{Key} : '';
-
-    # check if a translation is possible
-    if ( defined $Param{LanguageObject} ) {
-
-        # translate value
-        $Value = $Param{LanguageObject}->FormatTimeString(
-            $Value,
-            'DateFormatShort',
-        );
-    }
-
-    return $Value;
-}
-
-=begin Internal:
-
-=item _ConvertDate2DateTime()
-
-Append hh:mm:ss if only the ISO date was supplied to get a full date-time string.
-
-    my $DateTime = $BackendObject->_ConvertDate2DateTime(
-        '2017-01-01',
-    );
-
-Returns
-
-    $DataTime = '2017-01-01 00:00:00'
-
-=cut
-
-sub _ConvertDate2DateTime {
-    my ( $Self, $Value ) = @_;
-
-    if ( $Value && $Value =~ m{ \A \d{4}-\d{2}-\d{2} \z }xms ) {
-        $Value .= ' 00:00:00';
-    }
-
-    return $Value;
-}
-
 1;
 
-=end Internal:
-
 =back
 
 =head1 TERMS AND CONDITIONS
