@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::ProcessManagement::TransitionAction::TicketCreate;
@@ -94,7 +94,7 @@ sub new {
             PendingTime     => '2011-12-23 23:05:00', # optional (for pending states)
             PendingTimeDiff => 123 ,                  # optional (for pending states)
 
-            # article required:
+            # article required: (if one of them is not present, article will not be created without any error message)
             ArticleType      => 'note-internal',                        # note-external|phone|fax|sms|...
                                                                         #   excluding any email type
             SenderType       => 'agent',                                # agent|system|customer
@@ -185,7 +185,7 @@ sub Run {
         )
     {
         if ( defined $Param{Config}->{$Attribute} ) {
-            $TicketParam{$Attribute} = $Param{Config}->{$Attribute};
+            $TicketParam{$Attribute} = $Param{Config}->{$Attribute}
         }
     }
 
@@ -293,44 +293,64 @@ sub Run {
         )
     {
         if ( defined $Param{Config}->{$Attribute} ) {
-            $ArticleParam{$Attribute} = $Param{Config}->{$Attribute};
+            $ArticleParam{$Attribute} = $Param{Config}->{$Attribute}
         }
     }
 
-    # check ArticleType
-    if ( $ArticleParam{ArticleType} =~ m{\A email }msxi ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => $CommonMessage
-                . "ArticleType $Param{Config}->{ArticleType} is not supported",
-        );
-        return;
+    # check if article can be created
+    my $ArticleCreate = 1;
+    for my $Needed (qw(ArticleType SenderType ContentType Subject Body HistoryType HistoryComment)) {
+        if ( !$ArticleParam{$Needed} ) {
+            $ArticleCreate = 0;
+        }
     }
 
-    # create article for the new ticket
-    my $ArticleID = $TicketObject->ArticleCreate(
-        %ArticleParam,
-        TicketID => $TicketID,
-        UserID   => $Param{UserID},
-    );
-    if ( !$ArticleID ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => $CommonMessage
-                . "Couldn't create Article on Ticket: $TicketID from Ticket: "
-                . $Param{Ticket}->{TicketID} . '!',
-        );
-        return;
-    }
+    my $ArticleID;
 
-    # set time units
-    if ( $Param{Config}->{TimeUnit} ) {
-        $TicketObject->TicketAccountTime(
-            TicketID  => $TicketID,
-            ArticleID => $ArticleID,
-            TimeUnit  => $Param{Config}->{TimeUnit},
-            UserID    => $Param{UserID},
-        );
+    if ($ArticleCreate) {
+
+        my $ValidArticleType = 1;
+
+        # check ArticleType
+        if ( $ArticleParam{ArticleType} =~ m{\A email }msxi ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => $CommonMessage
+                    . "ArticleType $Param{Config}->{ArticleType} is not supported",
+            );
+            $ValidArticleType = 0;
+        }
+
+        if ($ValidArticleType) {
+
+            # create article for the new ticket
+            $ArticleID = $TicketObject->ArticleCreate(
+                %ArticleParam,
+                TicketID => $TicketID,
+                UserID   => $Param{UserID},
+            );
+
+            if ( !$ArticleID ) {
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message  => $CommonMessage
+                        . "Couldn't create Article on Ticket: $TicketID from Ticket: "
+                        . $Param{Ticket}->{TicketID} . '!',
+                );
+            }
+            else {
+
+                # set time units
+                if ( $Param{Config}->{TimeUnit} ) {
+                    $TicketObject->TicketAccountTime(
+                        TicketID  => $TicketID,
+                        ArticleID => $ArticleID,
+                        TimeUnit  => $Param{Config}->{TimeUnit},
+                        UserID    => $Param{UserID},
+                    );
+                }
+            }
+        }
     }
 
     # set dynamic fields for ticket and article
@@ -361,6 +381,10 @@ sub Run {
 
         my $ObjectID = $TicketID;
         if ( $DynamicFieldConfig->{ObjectType} ne 'Ticket' ) {
+
+            # skip article dynamic fields if Article was not created
+            next DYNAMICFIELD if !$ArticleCreate || !$ArticleID;
+
             $ObjectID = $ArticleID;
         }
 
@@ -460,10 +484,10 @@ sub Run {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
