@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SupportDataCollector::Plugin::Database::mysql::Charset;
@@ -11,7 +11,7 @@ package Kernel::System::SupportDataCollector::Plugin::Database::mysql::Charset;
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::SupportDataCollector::PluginBase);
+use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
 use Kernel::Language qw(Translatable);
 
@@ -54,17 +54,7 @@ sub Run {
 
     $DBObject->Prepare( SQL => "show variables like 'character_set_database'" );
     while ( my @Row = $DBObject->FetchrowArray() ) {
-        if ( $Row[1] =~ /utf8mb4/i ) {
-            $Self->AddResultProblem(
-                Identifier => 'ServerEncoding',
-                Label      => Translatable('Server Database Charset'),
-                Value      => $Row[1],
-                Message    => Translatable(
-                    "This character set is not yet supported, please see https://bugs.otrs.org/show_bug.cgi?id=12361. Please convert your database to the character set 'utf8'."
-                ),
-            );
-        }
-        elsif ( $Row[1] =~ /utf8/i ) {
+        if ( $Row[1] =~ /utf8/i ) {
             $Self->AddResultOk(
                 Identifier => 'ServerEncoding',
                 Label      => Translatable('Server Database Charset'),
@@ -76,17 +66,15 @@ sub Run {
                 Identifier => 'ServerEncoding',
                 Label      => Translatable('Server Database Charset'),
                 Value      => $Row[1],
-                Message    => Translatable("The setting character_set_database needs to be 'utf8'."),
+                Message    => Translatable('Setting character_set_database needs to be UNICODE or UTF8.'),
             );
         }
     }
 
     my @TablesWithInvalidCharset;
-
-    # Views have engine == null, ignore those.
-    $DBObject->Prepare( SQL => 'show table status where engine is not null' );
+    $DBObject->Prepare( SQL => 'show table status' );
     while ( my @Row = $DBObject->FetchrowArray() ) {
-        if ( $Row[14] =~ /^utf8mb4/i || $Row[14] !~ /^utf8/i ) {
+        if ( $Row[14] !~ /^utf8/i ) {
             push @TablesWithInvalidCharset, $Row[0];
         }
     }
@@ -95,7 +83,7 @@ sub Run {
             Identifier => 'TableEncoding',
             Label      => Translatable('Table Charset'),
             Value      => join( ', ', @TablesWithInvalidCharset ),
-            Message    => Translatable("There were tables found which do not have 'utf8' as charset."),
+            Message    => Translatable('There were tables found which do not have utf8 as charset.'),
         );
     }
     else {
