@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Ticket::TicketACL;
@@ -1152,27 +1152,17 @@ sub _GetChecks {
 
         # check if is a dynamic field with data
         next TICKETATTRIBUTE if $TicketAttribute !~ m{ \A DynamicField_ }smx;
-        next TICKETATTRIBUTE if !defined $Checks{Ticket}->{$TicketAttribute};
-        next TICKETATTRIBUTE if !length $Checks{Ticket}->{$TicketAttribute};
-
-        if (
+        next TICKETATTRIBUTE if !$Checks{Ticket}->{$TicketAttribute};
+        next TICKETATTRIBUTE if
             ref $Checks{Ticket}->{$TicketAttribute} eq 'ARRAY'
-            && !IsArrayRefWithData( $Checks{Ticket}->{$TicketAttribute} )
-            )
-        {
-            next TICKETATTRIBUTE;
-        }
+            && !IsArrayRefWithData( $Checks{Ticket}->{$TicketAttribute} );
 
         # compare if data is different and skip on same data
-        if (
-            $Checks{DynamicField}->{$TicketAttribute}
-            && !DataIsDifferent(
+        if ( $Checks{DynamicField}->{$TicketAttribute} ) {
+            next TICKETATTRIBUTE if !DataIsDifferent(
                 Data1 => $Checks{Ticket}->{$TicketAttribute},
                 Data2 => $Checks{DynamicField}->{$TicketAttribute},
-            )
-            )
-        {
-            next TICKETATTRIBUTE;
+            );
         }
 
         $Checks{DynamicField}->{$TicketAttribute} = $Checks{Ticket}->{$TicketAttribute};
@@ -1185,16 +1175,10 @@ sub _GetChecks {
 
         # check if is a dynamic field with data
         next TICKETATTRIBUTE if $TicketAttribute !~ m{ \A DynamicField_ }smx;
-        next TICKETATTRIBUTE if !defined $ChecksDatabase{Ticket}->{$TicketAttribute};
-        next TICKETATTRIBUTE if !length $ChecksDatabase{Ticket}->{$TicketAttribute};
-
-        if (
+        next TICKETATTRIBUTE if !$ChecksDatabase{Ticket}->{$TicketAttribute};
+        next TICKETATTRIBUTE if
             ref $ChecksDatabase{Ticket}->{$TicketAttribute} eq 'ARRAY'
-            && !IsArrayRefWithData( $ChecksDatabase{Ticket}->{$TicketAttribute} )
-            )
-        {
-            next TICKETATTRIBUTE;
-        }
+            && !IsArrayRefWithData( $ChecksDatabase{Ticket}->{$TicketAttribute} );
 
         $ChecksDatabase{DynamicField}->{$TicketAttribute} = $ChecksDatabase{Ticket}->{$TicketAttribute};
     }
@@ -1210,29 +1194,24 @@ sub _GetChecks {
         my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
 
         for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-            my @Groups = $GroupObject->GroupMemberList(
+
+            my %Groups = $GroupObject->PermissionUserGet(
                 UserID => $Param{UserID},
-                Result => 'Name',
                 Type   => $Type,
             );
-            $User{"Group_$Type"} = \@Groups;
+
+            my @GroupNames = sort values %Groups;
+
+            $User{"Group_$Type"} = \@GroupNames;
         }
 
-        my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+        my %RoleIDs = $GroupObject->PermissionUserRoleGet(
             UserID => $Param{UserID},
-            Result => 'ID',
         );
-        my @Roles;
-        ROLEID:
-        for my $RoleID (@RoleIDs) {
-            my $RoleName = $GroupObject->RoleLookup(
-                RoleID => $RoleID,
-            );
-            next ROLEID if !$RoleName;
-            push @Roles, $RoleName;
-        }
-        $User{Role} = \@Roles;
 
+        my @RoleNames = sort values %RoleIDs;
+
+        $User{Role}           = \@RoleNames;
         $Checks{User}         = \%User;
         $ChecksDatabase{User} = \%User;
     }
@@ -1255,6 +1234,7 @@ sub _GetChecks {
                 Result => 'Name',
                 Type   => $Type,
             );
+
             $CustomerUser{"Group_$Type"} = \@Groups;
         }
 
@@ -1538,7 +1518,7 @@ sub _GetChecks {
 
         # use priority data (if given)
         if ( $Param{NewPriorityID} && !$Param{PriorityID} ) {
-            $Param{PriorityID} = $Param{NewPriorityID};
+            $Param{PriorityID} = $Param{NewPriorityID}
         }
 
         if ( $Param{PriorityID} ) {
@@ -1679,8 +1659,8 @@ sub _GetChecks {
 
     # use state data (if given)
     if ( $CheckAll || $RequiredChecks{State} ) {
-        if ( !$Param{StateID} ) {
-            $Param{StateID} = $Param{NextStateID} || $Param{NewStateID};
+        if ( $Param{NextStateID} && !$Param{StateID} ) {
+            $Param{StateID} = $Param{NextStateID}
         }
         if ( $Param{StateID} ) {
             my %State = $StateObject->StateGet(
@@ -1772,29 +1752,24 @@ sub _GetChecks {
                 UserID => $Param{OwnerID},
             );
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                my @Groups = $GroupObject->GroupMemberList(
+
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $Param{OwnerID},
-                    Result => 'Name',
                     Type   => $Type,
                 );
-                $Owner{"Group_$Type"} = \@Groups;
+
+                my @GroupNames = sort values %Groups;
+
+                $Owner{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $Param{OwnerID},
-                Result => 'ID',
             );
-            my @Roles;
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-                next ROLEID if !$RoleName;
-                push @Roles, $RoleName;
-            }
-            $Owner{Role} = \@Roles;
 
+            my @RoleNames = sort values %RoleIDs;
+
+            $Owner{Role}   = \@RoleNames;
             $Checks{Owner} = \%Owner;
 
             # update or add owner information to the ticket check
@@ -1809,29 +1784,24 @@ sub _GetChecks {
                 UserID => $OwnerID,
             );
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                my @Groups = $GroupObject->GroupMemberList(
+
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $OwnerID,
-                    Result => 'Name',
                     Type   => $Type,
                 );
-                $Owner{"Group_$Type"} = \@Groups;
+
+                my @GroupNames = sort values %Groups;
+
+                $Owner{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $OwnerID,
-                Result => 'ID',
             );
-            my @Roles;
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-                next ROLEID if !$RoleName;
-                push @Roles, $RoleName;
-            }
-            $Owner{Role} = \@Roles;
 
+            my @RoleNames = sort values %RoleIDs;
+
+            $Owner{Role}   = \@RoleNames;
             $Checks{Owner} = \%Owner;
 
             # update or add owner information to the ticket check
@@ -1846,29 +1816,24 @@ sub _GetChecks {
                     UserID => $Checks{Ticket}->{OwnerID},
                 );
                 for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                    my @Groups = $GroupObject->GroupMemberList(
+
+                    my %Groups = $GroupObject->PermissionUserGet(
                         UserID => $Checks{Ticket}->{OwnerID},
-                        Result => 'Name',
                         Type   => $Type,
                     );
-                    $Owner{"Group_$Type"} = \@Groups;
+
+                    my @GroupNames = sort values %Groups;
+
+                    $Owner{"Group_$Type"} = \@GroupNames;
                 }
 
-                my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+                my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                     UserID => $Checks{Ticket}->{OwnerID},
-                    Result => 'ID',
                 );
-                my @Roles;
-                ROLEID:
-                for my $RoleID (@RoleIDs) {
-                    my $RoleName = $GroupObject->RoleLookup(
-                        RoleID => $RoleID,
-                    );
-                    next ROLEID if !$RoleName;
-                    push @Roles, $RoleName;
-                }
-                $Owner{Role} = \@Roles;
 
+                my @RoleNames = sort values %RoleIDs;
+
+                $Owner{Role}   = \@RoleNames;
                 $Checks{Owner} = \%Owner;
             }
         }
@@ -1892,29 +1857,24 @@ sub _GetChecks {
                 UserID => $ChecksDatabase{Ticket}->{OwnerID},
             );
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                my @Groups = $GroupObject->GroupMemberList(
+
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $ChecksDatabase{Ticket}->{OwnerID},
-                    Result => 'Name',
                     Type   => $Type,
                 );
-                $Owner{"Group_$Type"} = \@Groups;
+
+                my @GroupNames = sort values %Groups;
+
+                $Owner{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $ChecksDatabase{Ticket}->{OwnerID},
-                Result => 'ID',
             );
-            my @Roles;
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-                next ROLEID if !$RoleName;
-                push @Roles, $RoleName;
-            }
-            $Owner{Role} = \@Roles;
 
+            my @RoleNames = sort values %RoleIDs;
+
+            $Owner{Role}           = \@RoleNames;
             $ChecksDatabase{Owner} = \%Owner;
         }
     }
@@ -1928,29 +1888,24 @@ sub _GetChecks {
                 UserID => $Param{ResponsibleID},
             );
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                my @Groups = $GroupObject->GroupMemberList(
+
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $Param{ResponsibleID},
-                    Result => 'Name',
                     Type   => $Type,
                 );
-                $Responsible{"Group_$Type"} = \@Groups;
+
+                my @GroupNames = sort values %Groups;
+
+                $Responsible{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $Param{ResponsibleID},
-                Result => 'ID',
             );
-            my @Roles;
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-                next ROLEID if !$RoleName;
-                push @Roles, $RoleName;
-            }
-            $Responsible{Role} = \@Roles;
 
+            my @RoleNames = sort values %RoleIDs;
+
+            $Responsible{Role}   = \@RoleNames;
             $Checks{Responsible} = \%Responsible;
 
             # update or add responsible information to the ticket check
@@ -1965,29 +1920,24 @@ sub _GetChecks {
                 UserID => $ResponsibleID,
             );
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                my @Groups = $GroupObject->GroupMemberList(
+
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $ResponsibleID,
-                    Result => 'Name',
                     Type   => $Type,
                 );
-                $Responsible{"Group_$Type"} = \@Groups;
+
+                my @GroupNames = sort values %Groups;
+
+                $Responsible{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $ResponsibleID,
-                Result => 'ID',
             );
-            my @Roles;
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-                next ROLEID if !$RoleName;
-                push @Roles, $RoleName;
-            }
-            $Responsible{Role} = \@Roles;
 
+            my @RoleNames = sort values %RoleIDs;
+
+            $Responsible{Role}   = \@RoleNames;
             $Checks{Responsible} = \%Responsible;
 
             # update or add responsible information to the ticket check
@@ -2002,29 +1952,24 @@ sub _GetChecks {
                     UserID => $Checks{Ticket}->{ResponsibleID},
                 );
                 for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
-                    my @Groups = $GroupObject->GroupMemberList(
+
+                    my %Groups = $GroupObject->PermissionUserGet(
                         UserID => $Checks{Ticket}->{ResponsibleID},
-                        Result => 'Name',
                         Type   => $Type,
                     );
-                    $Responsible{"Group_$Type"} = \@Groups;
+
+                    my @GroupNames = sort values %Groups;
+
+                    $Responsible{"Group_$Type"} = \@GroupNames;
                 }
 
-                my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+                my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                     UserID => $Checks{Ticket}->{ResponsibleID},
-                    Result => 'ID',
                 );
-                my @Roles;
-                ROLEID:
-                for my $RoleID (@RoleIDs) {
-                    my $RoleName = $GroupObject->RoleLookup(
-                        RoleID => $RoleID,
-                    );
-                    next ROLEID if !$RoleName;
-                    push @Roles, $RoleName;
-                }
-                $Responsible{Role} = \@Roles;
 
+                my @RoleNames = sort values %RoleIDs;
+
+                $Responsible{Role}   = \@RoleNames;
                 $Checks{Responsible} = \%Responsible;
             }
         }
@@ -2052,35 +1997,23 @@ sub _GetChecks {
 
             for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
 
-                my @Groups = $GroupObject->GroupMemberList(
+                my %Groups = $GroupObject->PermissionUserGet(
                     UserID => $ChecksDatabase{Ticket}->{ResponsibleID},
-                    Result => 'Name',
                     Type   => $Type,
                 );
 
-                $Responsible{"Group_$Type"} = \@Groups;
+                my @GroupNames = sort values %Groups;
+
+                $Responsible{"Group_$Type"} = \@GroupNames;
             }
 
-            my @RoleIDs = $GroupObject->GroupUserRoleMemberList(
+            my %RoleIDs = $GroupObject->PermissionUserRoleGet(
                 UserID => $ChecksDatabase{Ticket}->{ResponsibleID},
-                Result => 'ID',
             );
-            my @Roles;
 
-            ROLEID:
-            for my $RoleID (@RoleIDs) {
-
-                my $RoleName = $GroupObject->RoleLookup(
-                    RoleID => $RoleID,
-                );
-
-                next ROLEID if !$RoleName;
-
-                push @Roles, $RoleName;
-            }
-
-            $Responsible{Role} = \@Roles;
+            my @RoleNames = sort values %RoleIDs;
 
+            $Responsible{Role}           = \@RoleNames;
             $ChecksDatabase{Responsible} = \%Responsible;
         }
     }
@@ -2246,10 +2179,10 @@ sub _CompareMatchWithData {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
